<!--
************************************************************************
Installer.buildfile

	Used to construct the MSI package for the Selenium Toolkit for .NET
	
	Usage:
	
		To create 32bit msi
			nant -buildfile=installer.buildfile createmsi -D:platform=x86 -D:version=0.8.3.0
			
************************************************************************
-->
<project name="installer" default="createmsi">
	<description>Creates the MSI Package</description>

	<!-- 
	************************************************************************
	SETTINGS:
	-->
	<property name="base.dir" value="${directory::get-current-directory()}" />
	<property name="wix.dir"
			  value="${path::combine(base.dir,'lib\wix\v3.0\')}" />
	<loadtasks assembly="${wix.dir}\Microsoft.Tools.WindowsInstallerXml.NAntTasks.dll" />
	
	<!-- 
	************************************************************************
	CREATEMSI:
		Description:
			Creates MSI package.
			Assumes that contents reside in <current-folder>\package\
	-->
	<target name="createmsi"
		    description="Creates the MSI package">
		
		<property name="install.src.dir" value="${path::combine(base.dir,'SeleniumToolkit.Install.Wix')}" />
		
		<echo message="source dir = ${install.src.dir} " />
		
		<candle out="${base.dir}\obj\\" 
				exedir="${wix.dir}"
				verbose="false"
				rebuild="true"
				>
			<defines>
				<define name="Platform" value="${platform}" />
				<define name="Version"  value="${version}" />
			</defines>
			<sources basedir="${install.src.dir}">
				<include name="*.wxs" />
			</sources>
		</candle>
		
		<light out="${base.dir}\SeleniumToolkit-${version}-${platform}.msi"
			   exedir="${wix.dir}"
			   extensions="WixUIExtension"
			   rebuild="true"
			   suppresspdb="true">
			   <sources basedir="${base.dir}\obj">
					<include name="*.wixobj" />
			   </sources>
		</light>
	</target>
	
</project>