<project default="main">
  
  <!-- SOLUTION SETTINGS -->
  <property name="msbuild" value="${framework::get-framework-directory(framework::get-target-framework())}\msbuild.exe" />

  <!-- FOLDERS AND TOOLS -->
  <property name="nunit.dir" value="${environment::get-folder-path('ProgramFiles')}\NUnit ${nunit.version}\bin\net-2.0" />
  <property name="nunit.console" value="${nunit.dir}\nunit-console.exe" />
  <property name="nunit.addin.dir" value="${path::combine(nunit.dir, 'addins')}" />
  <property name="selenium.nunitaddin.dir" value="${directory::get-current-directory() + '\SeleniumToolkit.Nunit\bin\' + vs.config}" />
  <property name="selenium.nunitaddin" value="${path::combine(selenium.nunitaddin.dir, 'SeleniumToolkit.NUnitAddin.dll')}" />
  
  <!-- main -->
  <target name="main" depends="build,test">
  </target>

  <!-- build solution -->
  <target name="build" depends="version">

    <!-- compile using msbuild -->
    <exec program="${msbuild}"
      commandline="${vs.sln} /m /t:Clean;Rebuild /p:Configuration=${vs.config} /p:DefineConstants=&quot;${vs.constants}&quot;"
      workingdir="."
          />

  </target>
	
	<!-- generate version number -->
	<target name="version">
	<attrib file="AssemblyVersion.cs" readonly="false" if="${file::exists('AssemblyVersion.cs')}" />
    <asminfo output="AssemblyVersion.cs" language="CSharp">
      <imports>
        <import namespace="System" />
        <import namespace="System.Reflection" />
      </imports>
      <attributes>
        <attribute type="AssemblyVersionAttribute" value="${version}" />
        <attribute type="AssemblyFileVersionAttribute" value="${version}" />
      </attributes>
    </asminfo>
	</target>
	
  <!-- test entry point -->
  <target name="test">
    <call target="test-nunit" />
  </target>

  <target name="remove-nunitaddin">
    <!-- remove addin before executing these tests -->
	<property name="addin" value="${path::combine(nunit.addin.dir, 'SeleniumToolkit.NUnitAddin.dll')}" />
    <delete file="${addin}" if="${file::exists(addin)}" />
  </target>
  
  <target name="deploy-nunitaddin">
	<copy file="${selenium.nunitaddin}" todir="${nunit.addin.dir}"  overwrite="true" />
  </target>
  
	<!-- run nunit tests -->
	<target name="test-nunit">

    <call target="remove-nunitaddin"/>
    
    <foreach item="File" property="filename">
      <in>
        <items>
	        <include name="SeleniumToolkit.Tests\bin\${vs.config}\SeleniumToolkit.Tests.dll" />
          <include name="SeleniumToolkit.NUnit.Tests\bin\${vs.config}\SeleniumToolkit.NUnit.Tests.dll" />
        </items>
      </in>
      <do>
        <echo message="Testing ${filename}" />
        <exec program="${nunit.console}"
              workingdir="${path::get-directory-name(filename)}"
              commandline="${path::combine(directory::get-current-directory(),filename)}"
             />
      </do>
    </foreach>
    
	</target>

  <target name="test-run">
    <!-- update addin -->
    <call target="deploy-nunitaddin" />

    <foreach item="File" property="filename">
      <in>
        <items>
          <include name="NUnit.TestAssembly.TestCaseScenario\bin\${vs.config}\NUnit.TestAssembly.TestCaseScenario.dll" />
          <include name="NUnit.TestAssembly.FixtureScenario\bin\${vs.config}\NUnit.TestAssembly.FixtureScenario.dll" />
        </items>
      </in>
      <do>
        <echo message="Testing ${filename}" />
        <exec program="${nunit.console}"
              workingdir="${path::get-directory-name(filename)}"
              commandline="${path::combine(directory::get-current-directory(),filename)}"
             />
      </do>
    </foreach>
    
  </target>

</project>